"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultStyles = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const prop_types_1 = __importDefault(require("prop-types"));
const picker_1 = require("@react-native-community/picker");
const NewPickerStyle_1 = require("./NewPickerStyle");
Object.defineProperty(exports, "defaultStyles", { enumerable: true, get: function () { return NewPickerStyle_1.defaultStyles; } });
const SceneUtils_1 = __importDefault(require("../utils/SceneUtils"));
class RNPickerSelect extends react_1.default.Component {
    constructor(props) {
        super(props);
        const items = RNPickerSelect.handlePlaceholder({
            placeholder: props.placeholder,
        }).concat(props.items);
        const { selectedItem } = RNPickerSelect.getSelectedItem({
            items,
            key: props.itemKey,
            value: props.value,
        });
        this.state = {
            items,
            selectedItem,
            showPicker: false,
            animationType: undefined,
            orientation: 'portrait',
            doneDepressed: false,
        };
        this.onUpArrow = this.onUpArrow.bind(this);
        this.onDownArrow = this.onDownArrow.bind(this);
        this.onValueChange = this.onValueChange.bind(this);
        this.onOrientationChange = this.onOrientationChange.bind(this);
        this.setInputRef = this.setInputRef.bind(this);
        this.togglePicker = this.togglePicker.bind(this);
        this.renderInputAccessoryView = this.renderInputAccessoryView.bind(this);
    }
    static handlePlaceholder(obj) {
        const placeholder = obj === null || obj === void 0 ? void 0 : obj.placeholder;
        // const {placeholder} = obj??{}
        if (!(placeholder === null || placeholder === void 0 ? void 0 : placeholder.value)) {
            return [];
        }
        return [placeholder];
    }
    static getSelectedItem(data) {
        const { items, key, value } = data;
        let idx = items.findIndex((item) => {
            if (item.key && key) {
                return item.key == key;
            }
            return item.value == value;
        });
        if (idx === -1) {
            idx = 0;
        }
        return {
            selectedItem: items[idx] || {},
            idx,
        };
    }
    static getDerivedStateFromProps(nextProps, prevState) {
        // update items if items or placeholder prop changes
        const items = RNPickerSelect.handlePlaceholder({
            placeholder: nextProps.placeholder,
        }).concat(nextProps.items);
        const itemsChanged = prevState.items !== items;
        // update selectedItem if value prop is defined and differs from currently selected item
        const { selectedItem, idx } = RNPickerSelect.getSelectedItem({
            items,
            key: nextProps.itemKey,
            value: nextProps.value,
        });
        const selectedItemChanged = nextProps.value !== undefined &&
            prevState.selectedItem !== selectedItem;
        if (itemsChanged || selectedItemChanged) {
            if (selectedItemChanged) {
                nextProps.onValueChange(selectedItem.value, idx);
            }
            return Object.assign(Object.assign({}, (itemsChanged ? { items } : {})), (selectedItemChanged ? { selectedItem } : {}));
        }
        return null;
    }
    onUpArrow() {
        const { onUpArrow } = this.props;
        this.togglePicker(false, onUpArrow);
    }
    onDownArrow() {
        const { onDownArrow } = this.props;
        this.togglePicker(false, onDownArrow);
    }
    onValueChange(value, index) {
        const { onValueChange } = this.props;
        onValueChange(value, index);
        this.setState((prevState) => {
            return {
                selectedItem: prevState.items[index],
            };
        });
    }
    onOrientationChange(obj) {
        const { nativeEvent } = obj !== null && obj !== void 0 ? obj : {};
        this.setState({
            orientation: nativeEvent.orientation,
        });
    }
    setInputRef(ref) {
        this.inputRef = ref;
    }
    getPlaceholderStyle() {
        const { placeholder, style } = this.props;
        const { selectedItem } = this.state;
        if (!!(placeholder === null || placeholder === void 0 ? void 0 : placeholder.value) && selectedItem.label === placeholder.label) {
            return Object.assign(Object.assign({}, NewPickerStyle_1.defaultStyles.placeholder), style.placeholder);
        }
        return {};
    }
    triggerOpenCloseCallbacks() {
        const { onOpen, onClose } = this.props;
        const { showPicker } = this.state;
        if (!showPicker && onOpen) {
            onOpen();
        }
        if (showPicker && onClose) {
            onClose();
        }
    }
    togglePicker(animate = false, postToggleCallback) {
        const { modalProps, disabled } = this.props;
        const { showPicker } = this.state;
        if (disabled) {
            return;
        }
        if (!showPicker) {
            react_native_1.Keyboard.dismiss();
        }
        const animationType = modalProps && modalProps.animationType
            ? modalProps.animationType
            : 'slide';
        this.triggerOpenCloseCallbacks();
        this.setState((prevState) => {
            return {
                animationType: animate ? animationType : undefined,
                showPicker: !prevState.showPicker,
            };
        }, () => {
            if (postToggleCallback) {
                postToggleCallback();
            }
        });
    }
    renderPickerItems() {
        const { items } = this.state;
        return items.map((item) => {
            return (react_1.default.createElement(picker_1.Picker.Item, { label: item.label, value: item.value, key: item.key || item.label, color: item.color }));
        });
    }
    renderInputAccessoryView() {
        const { InputAccessoryView, doneText, onUpArrow, onDownArrow, onDonePress, style, touchableDoneProps, } = this.props;
        const { doneDepressed } = this.state;
        if (InputAccessoryView) {
            return react_1.default.createElement(InputAccessoryView, { testID: "custom_input_accessory_view" });
        }
        return (react_1.default.createElement(react_native_1.View, { style: [NewPickerStyle_1.defaultStyles.modalViewMiddle, style.modalViewMiddle], testID: "input_accessory_view" },
            react_1.default.createElement(react_native_1.View, { style: [NewPickerStyle_1.defaultStyles.chevronContainer, style.chevronContainer] },
                react_1.default.createElement(react_native_1.TouchableOpacity, { activeOpacity: onUpArrow ? 0.5 : 1, onPress: onUpArrow ? this.onUpArrow : null },
                    react_1.default.createElement(react_native_1.View, { style: [
                            NewPickerStyle_1.defaultStyles.chevron,
                            style.chevron,
                            NewPickerStyle_1.defaultStyles.chevronUp,
                            style.chevronUp,
                            onUpArrow
                                ? [NewPickerStyle_1.defaultStyles.chevronActive, style.chevronActive]
                                : {},
                        ] })),
                react_1.default.createElement(react_native_1.TouchableOpacity, { activeOpacity: onDownArrow ? 0.5 : 1, onPress: onDownArrow ? this.onDownArrow : null },
                    react_1.default.createElement(react_native_1.View, { style: [
                            NewPickerStyle_1.defaultStyles.chevron,
                            style.chevron,
                            NewPickerStyle_1.defaultStyles.chevronDown,
                            style.chevronDown,
                            onDownArrow
                                ? [NewPickerStyle_1.defaultStyles.chevronActive, style.chevronActive]
                                : {},
                        ] }))),
            react_1.default.createElement(react_native_1.TouchableOpacity, Object.assign({ testID: "done_button", onPress: () => {
                    this.togglePicker(true, onDonePress);
                }, onPressIn: () => {
                    this.setState({ doneDepressed: true });
                }, onPressOut: () => {
                    this.setState({ doneDepressed: false });
                }, hitSlop: { top: 4, right: 4, bottom: 4, left: 4 } }, touchableDoneProps),
                react_1.default.createElement(react_native_1.View, { testID: "needed_for_touchable" },
                    react_1.default.createElement(react_native_1.Text, { testID: "done_text", allowFontScaling: false, style: [
                            NewPickerStyle_1.defaultStyles.done,
                            style.done,
                            doneDepressed
                                ? [NewPickerStyle_1.defaultStyles.doneDepressed, style.doneDepressed]
                                : {},
                        ] }, doneText)))));
    }
    renderIcon() {
        const { style, Icon } = this.props;
        if (!Icon) {
            return null;
        }
        return (react_1.default.createElement(react_native_1.View, { testID: "icon_container", style: [NewPickerStyle_1.defaultStyles.iconContainer, style.iconContainer] },
            react_1.default.createElement(Icon, { testID: "icon" })));
    }
    renderTextInputOrChildren() {
        const { children, style, textInputProps } = this.props;
        const { selectedItem } = this.state;
        const containerStyle = react_native_1.Platform.OS === 'ios'
            ? style.inputIOSContainer
            : style.inputAndroidContainer;
        if (children) {
            return (react_1.default.createElement(react_native_1.View, { pointerEvents: "box-only", style: containerStyle }, children));
        }
        return (react_1.default.createElement(react_native_1.View, { pointerEvents: "box-only", style: containerStyle },
            react_1.default.createElement(react_native_1.TextInput, Object.assign({ testID: "text_input", style: [
                    react_native_1.Platform.OS === 'ios' ? style.inputIOS : style.inputAndroid,
                    this.getPlaceholderStyle(),
                    { fontFamily: SceneUtils_1.default.whitney_semibold, fontSize: 14, color: SceneUtils_1.default.text_color },
                ], value: selectedItem.inputLabel
                    ? selectedItem.inputLabel
                    : selectedItem.label, ref: this.setInputRef, editable: false }, textInputProps)),
            this.renderIcon()));
    }
    renderIOS() {
        const { style, modalProps, pickerProps, touchableWrapperProps } = this.props;
        const { animationType, orientation, selectedItem, showPicker } = this.state;
        return (react_1.default.createElement(react_native_1.View, { style: [NewPickerStyle_1.defaultStyles.viewContainer, style.viewContainer] },
            react_1.default.createElement(react_native_1.TouchableOpacity, Object.assign({ testID: "ios_touchable_wrapper", onPress: () => {
                    this.togglePicker(true);
                }, activeOpacity: 1 }, touchableWrapperProps), this.renderTextInputOrChildren()),
            react_1.default.createElement(react_native_1.Modal, Object.assign({ testID: "ios_modal", visible: showPicker, transparent: true, animationType: animationType, supportedOrientations: ['portrait', 'landscape'], onOrientationChange: this.onOrientationChange }, modalProps),
                react_1.default.createElement(react_native_1.TouchableOpacity, { style: [NewPickerStyle_1.defaultStyles.modalViewTop, style.modalViewTop], testID: "ios_modal_top", onPress: () => {
                        this.togglePicker(true);
                    } }),
                this.renderInputAccessoryView(),
                react_1.default.createElement(react_native_1.View, { style: [
                        NewPickerStyle_1.defaultStyles.modalViewBottom,
                        { height: orientation === 'portrait' ? 215 : 162 },
                        style.modalViewBottom,
                    ] },
                    react_1.default.createElement(picker_1.Picker, Object.assign({ testID: "ios_picker", mode: "dropdown", style: { color: '#fff', placeholderTextColor: '#fff' }, onValueChange: this.onValueChange, itemStyle: { fontSize: 20 }, selectedValue: selectedItem.value }, pickerProps), this.renderPickerItems())))));
    }
    renderAndroidHeadless() {
        const { disabled, Icon, style, pickerProps, onOpen, touchableWrapperProps, fixAndroidTouchableBug, } = this.props;
        const { selectedItem } = this.state;
        const Component = fixAndroidTouchableBug ? react_native_1.View : react_native_1.TouchableOpacity;
        return (react_1.default.createElement(Component, Object.assign({ testID: "android_touchable_wrapper", onPress: onOpen, activeOpacity: 1 }, touchableWrapperProps),
            react_1.default.createElement(react_native_1.View, { style: style.headlessAndroidContainer },
                this.renderTextInputOrChildren(),
                react_1.default.createElement(picker_1.Picker, Object.assign({ style: [
                        Icon ? { backgroundColor: 'transparent' } : {},
                        NewPickerStyle_1.defaultStyles.headlessAndroidPicker,
                        style.headlessAndroidPicker,
                    ], testID: "android_picker_headless", enabled: !disabled, onValueChange: this.onValueChange, selectedValue: selectedItem.value }, pickerProps), this.renderPickerItems()))));
    }
    renderAndroidNativePickerStyle() {
        const { disabled, Icon, style, pickerProps } = this.props;
        const { selectedItem } = this.state;
        return (react_1.default.createElement(react_native_1.View, { style: [NewPickerStyle_1.defaultStyles.viewContainer, style.viewContainer] },
            react_1.default.createElement(picker_1.Picker, Object.assign({ style: [
                    Icon ? { backgroundColor: 'transparent' } : {},
                    style.inputAndroid,
                    this.getPlaceholderStyle(),
                    { backgroundColor: 'transparent', minWidth: 80 }
                ], testID: "android_picker", enabled: !disabled, onValueChange: this.onValueChange, selectedValue: selectedItem.value }, pickerProps), this.renderPickerItems())));
    }
    renderWeb() {
        const { disabled, style, pickerProps } = this.props;
        const { selectedItem } = this.state;
        return (react_1.default.createElement(react_native_1.View, { style: [NewPickerStyle_1.defaultStyles.viewContainer, style.viewContainer] },
            react_1.default.createElement(picker_1.Picker, Object.assign({ style: [style.inputWeb], testID: "web_picker", enabled: !disabled, onValueChange: this.onValueChange, selectedValue: selectedItem.value }, pickerProps), this.renderPickerItems()),
            this.renderIcon()));
    }
    render() {
        const { children, useNativeAndroidPickerStyle } = this.props;
        if (react_native_1.Platform.OS === 'ios') {
            return this.renderIOS();
        }
        if (react_native_1.Platform.OS === 'web') {
            return this.renderWeb();
        }
        if (children || !useNativeAndroidPickerStyle) {
            return this.renderAndroidHeadless();
        }
        return this.renderAndroidNativePickerStyle();
    }
}
exports.default = RNPickerSelect;
RNPickerSelect.propTypes = {
    onValueChange: prop_types_1.default.func.isRequired,
    items: prop_types_1.default.arrayOf(prop_types_1.default.shape({
        label: prop_types_1.default.string.isRequired,
        value: prop_types_1.default.any.isRequired,
        inputLabel: prop_types_1.default.string,
        key: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.number]),
        color: prop_types_1.default.string,
    })).isRequired,
    value: prop_types_1.default.any,
    placeholder: prop_types_1.default.shape({
        label: prop_types_1.default.string,
        value: prop_types_1.default.any,
        key: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.number]),
        color: prop_types_1.default.string,
    }),
    disabled: prop_types_1.default.bool,
    itemKey: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.number]),
    style: prop_types_1.default.shape({}),
    children: prop_types_1.default.any,
    onOpen: prop_types_1.default.func,
    useNativeAndroidPickerStyle: prop_types_1.default.bool,
    fixAndroidTouchableBug: prop_types_1.default.bool,
    // Custom Modal props (iOS only)
    doneText: prop_types_1.default.string,
    onDonePress: prop_types_1.default.func,
    onUpArrow: prop_types_1.default.func,
    onDownArrow: prop_types_1.default.func,
    onClose: prop_types_1.default.func,
    // Modal props (iOS only)
    modalProps: prop_types_1.default.shape({}),
    // TextInput props
    textInputProps: prop_types_1.default.shape({}),
    // Picker props
    pickerProps: prop_types_1.default.shape({}),
    // Touchable Done props (iOS only)
    touchableDoneProps: prop_types_1.default.shape({}),
    // Touchable wrapper props
    touchableWrapperProps: prop_types_1.default.shape({}),
    // Custom Icon
    Icon: prop_types_1.default.func,
    InputAccessoryView: prop_types_1.default.func,
};
RNPickerSelect.defaultProps = {
    value: 100,
    placeholder: {
        label: 'Select an item...',
        value: null,
        color: '#9EA0A4',
    },
    disabled: false,
    itemKey: null,
    style: {},
    children: null,
    useNativeAndroidPickerStyle: true,
    fixAndroidTouchableBug: false,
    doneText: 'Done',
    onDonePress: null,
    onUpArrow: null,
    onDownArrow: null,
    onOpen: null,
    onClose: null,
    modalProps: {},
    textInputProps: {},
    pickerProps: {},
    touchableDoneProps: {},
    touchableWrapperProps: {},
    Icon: null,
    InputAccessoryView: null,
};
//# sourceMappingURL=NewPicker.js.map